@@ -12,42 +12,39 @@ use 5.002;
 use strict;
 use warnings;
 
-package Local::Payload;
-use Moo;
+{
+    package Local::Payload;
+    use Moo;
 
-has entity => (
-    is => 'rw',
-    isa => sub { die "Not a Net::IP::Identifier::Plugin\n"
-                    if (not $_[0]->does('Net::IP::Identifier_Role')); },
-);
-has ip => (
-    is => 'rw',
-    isa => sub { die "Not a Net::IP::Identifier::Net\n"
-                    if (not $_[0]->isa('Net::IP::Identifier::Net')); },
-);
-
-1;
+    has entity => (
+        is => 'rw',
+        isa => sub { die "Not a Net::IP::Identifier::Plugin\n"
+                        if (not $_[0]->does('Net::IP::Identifier_Role')); },
+    );
+    has ip => (
+        is => 'rw',
+        isa => sub { die "Not a Net::IP::Identifier::Net\n"
+                        if (not $_[0]->isa('Net::IP::Identifier::Net')); },
+    );
+}
 
 
 package Net::IP::Identifier;
-use Moo;
-
-use IO::File;
-use File::Spec;
-use Readonly;
 use Getopt::Long qw(:config pass_through);
-use Module::Pluggable;
+use File::Spec;
 use Net::IP::Identifier::Net;
 use Net::IP::Identifier::Binode;
-use Try::Tiny;
 use Net::IP::Identifier::Regex;
 use Carp;
+use Moo;
+use namespace::clean;
+use Module::Pluggable;
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 has joiner => (
     is => 'rw',
-    isa => sub { die "Not a string\n" if (ref $_); },
+    isa => sub { die "Not a string\n" if (ref $_[0]); },
     default => sub { ':' },
 );
 has cidr => (
@@ -60,7 +57,7 @@ has overlaps => (
     is => 'rw',
 );
 has re => ( # regular expressions for IP addresses
-    is => 'ro',
+    is => 'lazy',
     default => sub { Net::IP::Identifier::Regex->new },
 );
 
@@ -75,9 +72,9 @@ $myName [ options ] IP [ IP... ]
 If IP belongs to a known entity (a Net::IP::Identifier::Plugin),
 print the entity.
 
-IP may be dotted decimal format: N.N.N.N, CIDR format: N.N.N.N/W,
-or a filename from which IPs will be extracted.  If no IP is found,
-STDIN is opened.
+IP may be dotted decimal format: N.N.N.N, range format: N.N.N.N - N.N.N.N,
+CIDR format: N.N.N.N/W, or a filename from which IPs will be extracted.  If
+no IP or filename is found on the command line, STDIN is opened.
 
 Options (may be abbreviated):
     parents   => prepend Net::IP::Identifier objects of parent entities
@@ -118,12 +115,11 @@ sub run {
 
     unshift @ARGV, $filename if ($filename);
     if (not @ARGV) {
-        push @ARGV, '-';    # STDIN
+        $identifier->parse_fh(\*STDIN);
     }
 
-    for my $ii (0 .. $#ARGV) {
-        my $arg = $ARGV[$ii];
-        next if not defined $arg;
+    while (@ARGV) {
+        my $arg = shift @ARGV;
         if (-f $arg) {
             open my $fh, '<', $arg;
             croak "Can't open $arg for reading\n" if not $fh;
@@ -131,31 +127,15 @@ sub run {
             close $fh;
             next
         }
-        elsif (    $ARGV[$ii + 1]      # accept N.N.N.N - N.N.N.N for network blocks too
-                and $ARGV[$ii + 1] eq '-'
-                and $ARGV[$ii + 2]) {
-            $arg = "$arg-$ARGV[$ii + 2]";
-            $ii += 2;
-        }
-        elsif ($arg eq '-') {   # use STDIN?
-            $identifier->parse_fh(\*STDIN);
-        }
-        elsif ($arg) {
-            my ($ip, $error);
-            try {
-                $ip = Net::IP::Identifier::Net->new($arg);
-            } catch {
-                $error = $_;
-            };
-            if ($error) {
-                print "$myName: don't understand $arg\n";
-                print $error;
-            }
-            else {
-                print $identifier->identify($ip) || $ip, "\n";
-            }
+        elsif ($ARGV[0]        and  # accept N.N.N.N - N.N.N.N for network blocks too
+               $ARGV[0] eq '-' and
+               $ARGV[1]) {
+            $arg .= shift @ARGV . shift @ARGV;
         }
+
+        print $identifier->identify($arg) || $arg, "\n";
     }
+
     if ($overlaps) {
         for my $return (@{$identifier->tree_overlaps}) {
             my @r = map { join $identifier->joiner, $_->payload->entity, $_->payload->ip; } @{$return};
@@ -167,7 +147,7 @@ sub run {
 sub import {
     my ($class, @imports) = @_;
 
-    $imports = \@imports;   # save import list in class variable
+    $imports = \@imports if (@imports);   # save import list in class variable
 }
 
 sub parse_fh {
@@ -221,6 +201,7 @@ sub entities {
 
     if (@_ > 1) {
         undef $imports;         # override imports with @plugins
+#print "load args: ", join(' ', @plugins), "\n";
         $self->load_entities(@plugins);
     }
 
@@ -229,10 +210,12 @@ sub entities {
         # if no plugins yet loaded, check import list
         # no import list? load everything we can find
         if ($imports) {
+#print "load imports ", join(' ', @{$imports}), "\n";
             $self->load_entities($imports);
             undef $imports;     # only the first time
         }
         else {
+#print "load imports ", join(' ', $self->plugins), "\n";
             $self->load_entities([ $self->plugins ]);
         }
 
@@ -369,7 +352,7 @@ Net::IP::Identifier - Identify IPs that fall within collections of network block
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -379,7 +362,12 @@ version 0.086
 
 =head1 DESCRIPTION
 
-Net::IP::Identifier represents...
+Net::IP::Identifier identifies IP addresses or netblocks that lie within a
+select group of pre-identified netblocks.  This package contains a
+collection of identified entities (in the Plugins directory).  These are
+either large, well known entities (i.e: Google and Microsoft) or they are
+owners of netblocks that have produced a lot of SPAM that arrived at my
+server.
 
 =head2 Methods
 
@@ -397,7 +385,7 @@ Input (from a file or the command line) is scanned for things that look
 like IP (v4 or v6) addresses or blocks.  For each matching item, the
 B<Net::IP::Identifer> object's B<identify> method is called on it (see
 below).  If a match is found, the entity is printed, otherwise the original
-matched item is printed.
+IP is printed.
 
 Example:
 
@@ -473,7 +461,7 @@ If the IP cannot be identified with an entity, B<undef> is returned.
 If the IP belongs to an included identity (see PLUGINS), the return value is
 modified by the format flags.
 
-When all modifiers false, the return value is the name of
+When all modifiers are false, the return value is the name of
 the entity (e.g: 'Yahoo').
 
 When B<cidr> is true, the Net::IP::Identifier::Net object of the matching
@@ -511,7 +499,7 @@ wide netblocks.  Let's not congest CPAN with a multitude of class C
 netblocks.
 
 Entities with child netblocks can name them in a B<children> subroutine
-(see Microsoft and Yahoo for examples).  If you want to add a netblock as a
+(see Microsoft and Hotmail for example).  If you want to add a netblock as a
 child, you'll need to arrange with the parent's CPAN owner to add it.  This
 relationship is independant of the network hierarchy, and is currently ignored
 by Net::IP::Identifier.
