@@ -15,11 +15,12 @@ use warnings;
 $DB::deep = 150;    # IPv6 needs 128 plus some headroom
 
 package Net::IP::Identifier::Binode;
+use Carp;
+use Math::BigInt;
 use Moo;
 use namespace::clean;
-use Carp;
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 has zero => (
     is => 'rw',
@@ -54,6 +55,7 @@ sub bin_to_ip {
     return join '.', @results;
 }
 
+our $path = Math::BigInt->new(0);
 sub construct {
     my ($self, $path) = @_;
 
@@ -73,7 +75,7 @@ sub construct {
                 }
             }
             else {
-                $node = $self;
+                $node = $self;  # when we reach the end
             }
             return 0;   # always continue
         }
@@ -118,8 +120,11 @@ sub _traverse_width_first {
 
     return if $callback->($self, $level, @extra);
 
+#$path <<= 1;
     $self->zero->_traverse_width_first($level + 1, $callback, @extra) if ($self->zero);
+#$path |= 1;
     $self->one ->_traverse_width_first($level + 1, $callback, @extra) if ($self->one);
+#$path >>= 1;
 }
 
 sub traverse_depth_first {
@@ -134,8 +139,12 @@ sub _traverse_depth_first {
     my ($self, $level, $callback, @extra) = @_;
 
     my $stop;
+#print "path=", $path->as_hex, "\n";
+#$path <<= 1;
     $stop = $self->zero->_traverse_depth_first($level + 1, $callback, @extra) if ($self->zero);
+#$path |= 1;
     $stop = $self->one ->_traverse_depth_first($level + 1, $callback, @extra) if (not $stop and $self->one);
+#$path >>= 1;
 
     $callback->($self, $level, @extra) if (not $stop);
 }
@@ -154,7 +163,7 @@ Net::IP::Identifier::Binode - A node in the binary tree
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -194,7 +203,7 @@ create a Local::Payload object to hold the B<$payload>.
 Construct a branch of the tree out to B<$path>.  New child nodes are
 created as necessary.  The return value is the node at $path.
 
-=item follow($path, $callback, [ @extra ] );
+=item $node->follow($path, $callback, [ @extra ] );
 
 Descend the binary tree, following B<$path>.  B<$path> should be a string
 where the length represents the number of levels to descend, false
@@ -206,15 +215,16 @@ node.  It is called thusly:
 
     $callback->($self, $path, $level, @extra);
 
-where B<$self> if the current node, B<$path> is the original path,
+where B<$self> is the current node, B<$path> is the original path,
 B<$level> is the current index into B<$path>, and @extra are just passed
-from the along original call.
+along from the original call.
 
 The callback must return true to stop following (abort the descent), or
 false to continue normally.
 
-=item traverse_width_first($callback, [ @extra ] );
-=item traverse_depth_first($callback, [ @extra ] );
+=item $node->traverse_width_first($callback, [ @extra ] );
+
+=item $node->traverse_depth_first($callback, [ @extra ] );
 
 Traverse the binary tree, either width or depth first.
 
@@ -223,9 +233,9 @@ node.  It is called thusly:
 
     $callback->($self, $level, @extra);
 
-where B<$self> if the current node, B<$level> is the current depth
-(starting with 0 at the entry node), and @extra are just passed from the
-along original call.
+where B<$self> is the current node, B<$level> is the current depth
+(starting with 0 at the entry node), and @extra are just passed along from
+the original call.
 
 The callback must return true to stop following (abort the descent), or
 false to continue normally.
