@@ -1,6 +1,6 @@
 #===============================================================================
 #      PODNAME:  Net::IP::Identifier::Net
-#     ABSTRACT:  subclass Net::IP to add as_string method and stringification
+#     ABSTRACT:  subclass Net::IP to add some functionality
 #
 #       AUTHOR:  Reid Augustin (REID)
 #        EMAIL:  reid@hellosix.com
@@ -17,11 +17,10 @@ use parent 'Net::IP';
 use Math::BigInt;
 use Carp;
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 use overload (
-    fallback => 1,
-    '""' => 'as_string',
+    '""' => 'print',
 );
 
 # Accept any of:
@@ -32,28 +31,45 @@ sub new {
 
     croak "Must have exactly one argument to 'new'\n" if (@_ != 2);
     if (ref $net) {
-        return $net if ($net->isa($class)); # already correct
-    }
-    else {
-        $net = $class->SUPER::new($net);   # create from string as the super class
-    }
-    bless $net, $class;   # rebless to this package
+        return $net if (ref $net eq __PACKAGE__); # already correct
 
-    return $net;
+        # it's an object, but wrong kind
+        my $src_str;
+        $src_str = $net->src_str if ($net->can('src_str'));
+        bless $net, $class;   # rebless to this package
+        # make sure we have a source string
+        $net->src_str($src_str || $net->print);
+        return $net;
+    }
+    my $self = $class->SUPER::new($net);
+    bless $self, $class;    # rebless to this package
+    $self->src_str($net);   # set the source string
+
+    return $self;
+}
+
+sub src_str {
+    my ($self, $new) = @_;
+
+    if (@_ > 1) {
+        $self->{src_str} = $new;
+    }
+    return $self->{src_str};
 }
 
 # print an int as a dotted decimal quad
 sub int_to_ip {
     my ($self, $ip, $version) = @_;
 
-    $version = $self->version || 4 if (not $version);
+    $version ||= $self->version || 4;
     my @parts;
     if ($version eq '6') {
         while ($ip or @parts < 8) {
             unshift @parts, $ip & 0xffff;
             $ip >>= 16;
         }
-        return join(':', map { sprintf "%x", $_ } @parts);   # yeah, should remove some colons...
+        my $addr = join(':', map { sprintf "%x", $_ } @parts);
+        return Net::IP::ip_compress_address($addr, 6);
     }
 
     # else IPv4
@@ -113,10 +129,12 @@ if (0) {
     return(@low, @high);
 }
 
-# add method to convert range into cidrs
+# method to convert range into cidrs
 sub range_to_cidrs {
     my ($self) = @_;
 
+    return $self if ($self->prefixlen); # don't need to split
+
     return $self->split_range(
         $self->masklen - 1,
         $self->intip,
@@ -129,6 +147,8 @@ my $zero_v6 = '0' x 128;
 sub differ {
     my ($self) = @_;
 
+    # xor with zero mask also to ensure proper upper bits
+    return $self->binip ^ $self->last_bin ^ ($self->version == 6 ? $zero_v6 : $zero_v4);
 }
 
 # return the inverse of the prefixlen, the length of the 1s in the mask
@@ -139,7 +159,7 @@ sub masklen {
     my ($self) = @_;
 
     my $len = $self->version == 6 ? 128 : 32;
-    my $differ = $self->binip ^ $self->last_bin ^ ($self->version == 6 ? $zero_v6 : $zero_v4);
+    my $differ = $self->differ;
     my $idx = index($differ, '1');
     return 0 if $idx < 0;
     return $len - $idx;
@@ -153,16 +173,26 @@ sub masked_ip {
     return substr($self->binip, 0, $len - $self->masklen);
 }
 
-# add a method to print the IP without prefixlen (for single IPs) or
-# network with prefixlength
-sub as_string {
+# override print: bare IP (without prefixlen) for single IPs or network
+# with prefixlength if CIDR, or as range if not single and not CIDR
+sub print {
     my ($self) = @_;
 
+    return $self->ip if ($self->ip eq $self->last_ip);
     if (defined $self->prefixlen) {
-        return $self->ip if (not defined $self->prefixlen);
-        return sprintf "%s/%s", $self->ip, $self->prefixlen;
+        if ($self->version eq 6) {
+            return $self->SUPER::print;
+        }
+        return $self->ip . '/' . $self->prefixlen;
     }
-    return $self->print;    # range
+    return $self->ip . '-' . $self->last_ip;
+}
+
+# return ->ip, but compress if IPv6
+sub compressed_ip {
+    my ($self) = @_;
+
+    return Net::IP::ip_compress_address($self->ip, $self->version);
 }
 
 1;
@@ -175,11 +205,11 @@ __END__
 
 =head1 NAME
 
-Net::IP::Identifier::Net - subclass Net::IP to add as_string method and stringification
+Net::IP::Identifier::Net - subclass Net::IP to add some functionality
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -192,7 +222,7 @@ version 0.086
 B<Net::IP::Identifier::Net> subclasses B<Net::IP>.  IP can be any of the
 forms accepted by B<Net::IP>.
 
-Stringification is provided, and uses the B<as_string> method.
+Stringification is provided, and uses the B<print> method.
 
 =head2 Methods
 
@@ -212,11 +242,20 @@ masked with the inverse of the netmask.  This means you get the upper
 significant bits (the bits that don't change within this netblock).  The
 lower bits are removed.
 
-=item my $str = $net->as_string
+=item my $str = $net->print
 
-Returns a string.  For Net::IP::Identifier::Net objects which represent a
-single IP, the string is a dotted decimal (N.N.N.N).  If B<$ip> represents
-a netblock, the string is a CIDR (N.N.N.N/W).
+Override of Net::IP->print, returns a string.  For Net::IP::Identifier::Net
+objects which represent a single IP, the string is a dotted decimal quad
+(N.N.N.N).  If B<$ip> represents a netblock, the string is a CIDR
+(N.N.N.N/W) if possible, otherwise it is a range (N.N.N.N - N.N.N.N).
+
+Note that Net::IP->print adds '/32' to single IPs, and it shortens CIDRs if
+possible (like N.N/16).
+
+=item my $str = $net->compressed
+
+Returns a string.  Calls the Net::IP::ip_compress_address() method to
+shorten IPv6 addresses.
 
 =back
 
