@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::B2_Net;  # _ENTITY_REGEX_ B2.Net
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,27 +24,27 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known B2_Net Solutions (AS55286) IP blocks as of Sept 2014
-    $self->ips(qw(
-        23.229.0.0 - 23.229.127.255
-        23.236.128.0 - 23.236.255.255
-        23.250.0.0 - 23.250.127.255
-        23.254.0.0 - 23.254.127.255
-        69.4.80.0 - 69.4.95.255
-        69.58.0.0 - 69.58.15.255
-        104.144.0.0 - 104.144.255.255
-        104.227.0.0 - 104.227.255.255
-        107.152.128.0 - 107.152.255.255
-        138.128.0.0 - 138.128.127.255
-        192.157.48.0 - 192.157.63.255
-        192.186.128.0 - 192.186.191.255
-        192.198.96.0 - 192.198.127.255
-        192.241.64.0 - 192.241.127.255
-        198.20.160.0 - 198.20.191.255
-        198.154.80.0 - 198.154.95.255
-        192.157.48.0 - 192.157.63.255
-        198.245.64.0 - 198.245.79.255
-    ));
+    # List of known B2_Net Solutions (AS55286) IP blocks as of May 2015
+    $self->ips(
+        # 17 Network Blocks
+        '23.229.0.0/17',
+        '23.236.128.0/17',
+        '23.250.0.0/17',
+        '23.254.0.0/17',
+        '69.4.80.0/20',
+        '69.58.0.0/20',
+        '104.144.0.0/16',
+        '104.227.0.0/16',
+        '107.152.128.0/17',
+        '138.128.0.0/17',
+        '192.157.48.0/20',
+        '192.186.128.0/18',
+        '192.198.96.0/19',
+        '192.241.64.0/18',
+        '198.20.160.0/19',
+        '198.154.80.0/20',
+        '198.245.64.0/20',
+    );
     return $self;
 }
 
@@ -66,7 +66,7 @@ Net::IP::Identifier::Plugin::B2_Net - identify B2_Net Solutions (AS55286) owned
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
