@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::DataShack;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,21 +24,22 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known DataShack (AS33387) IP blocks as of Nov 2014
+    # List of known DataShack (AS33387) IP blocks as of May 2015
     # (apparently associated with WholeSale Internet and Zhou Pizhong)
-    $self->ips(qw(
-        63.141.224.0 - 63.141.255.255
-        74.91.16.0 - 74.91.31.255
-        107.150.32.0 - 107.150.63.255
-        142.54.160.0 - 142.54.191.255
-        173.208.166.0 - 173.208.166.255
-        173.208.250.0 - 173.208.250.255
-        192.151.144.0 - 192.151.159.255
-        192.187.96.0 - 192.187.127.255
-        198.204.224.0 - 198.204.255.255
-        199.168.96.0 - 199.168.103.255
-        2604:4300:: - 2604:4300:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF
-    ));
+    $self->ips(
+        # 11 Network Blocks
+        '63.141.224.0/19',
+        '74.91.16.0/20',
+        '107.150.32.0/19',
+        '142.54.160.0/19',
+        '173.208.166.0/24',
+        '173.208.250.0/24',
+        '192.151.144.0/20',
+        '192.187.96.0/19',
+        '198.204.224.0/19',
+        '199.168.96.0/21',
+        '2604:4300::/32',
+    );
     return $self;
 }
 
@@ -60,7 +61,7 @@ Net::IP::Identifier::Plugin::DataShack - identify DataShack (AS33387) owned IP a
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
