@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Enzu;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,31 +24,32 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Enzu/ScalableDNS IP blocks as of Nov 2014
-    $self->ips(qw(
-        23.88.0.0 - 23.89.255.255
-        23.244.0.0 - 23.245.255.255
-        37.77.80.0 - 37.77.95.255
-        38.126.44.0/23
-        104.151.0.0 - 104.151.255.255
-        104.202.0.0 - 104.203.255.255
-        107.183.0.0 - 107.183.255.255
-        172.246.0.0 - 172.246.255.255
-        184.105.219.0 - 184.105.219.255
-        188.215.80.0 - 188.215.87.255
-        188.215.104.0 - 188.215.111.255
-        192.80.128.0 - 192.80.191.255
-        192.157.192.0 - 192.157.255.255
-        198.56.128.0 - 198.56.255.255
-        198.71.80.0 - 198.71.95.255
-        198.98.96.0 - 198.98.127.255
-        199.48.68.0 - 199.48.71.255
-        199.188.72.0 - 199.188.75.255
-        199.193.248.0 - 199.193.255.255
-        199.229.232.0 - 199.229.235.255
-        199.231.208.0 - 199.231.215.255
-        2605:F700:: - 2605:F700:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF
-    ));
+    # List of known Enzu/ScalableDNS IP blocks as of May 2015
+    $self->ips(
+        # 22 Network Blocks
+        '23.88.0.0/15',
+        '23.244.0.0/15',
+        '37.77.80.0/20',
+        '104.151.0.0/16',
+        '104.202.0.0/15',
+        '107.183.0.0/16',
+        '172.246.0.0/16',
+        '184.105.219.0/24',
+        '188.215.80.0/21',
+        '188.215.104.0/21',
+        '192.80.128.0/18',
+        '192.157.192.0/18',
+        '198.56.128.0/17',
+        '198.71.80.0/20',
+        '198.98.96.0/19',
+        '199.48.68.0/22',
+        '199.188.72.0/22',
+        '199.193.248.0/21',
+        '199.229.232.0/22',
+        '199.231.208.0/21',
+        '2605:f700::/32',
+        '2a00:8c40::/32',
+    );
     return $self;
 }
 
@@ -70,7 +71,7 @@ Net::IP::Identifier::Plugin::Enzu - identify Enzu/ScalableDNS owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
