@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Eonix;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,22 +24,24 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Eonix (AS30693) IP blocks as of Oct 2014
-    $self->ips(qw(
-        23.90.0.0 - 23.90.63.255
-        23.231.0.0 - 23.231.127.255
-        50.2.0.0 - 50.3.255.255
-        75.75.224.0 - 75.75.255.255
-        104.140.0.0 - 104.140.255.255
-        104.206.0.0 - 104.206.255.255
-        107.158.0.0 - 107.158.255.255
-        170.130.0.0 - 170.130.255.255
-        173.44.128.0 - 173.44.255.255
-        173.213.64.0 - 173.213.127.255
-        173.232.0.0 - 173.232.255.255
-        206.214.64.0 - 206.214.95.255
-        208.89.216.0 - 208.89.223.255
-    ));
+    # List of known Eonix (AS30693) IP blocks as of May 2015
+    $self->ips(
+        # 14 Network Blocks
+        '23.90.0.0/18',
+        '23.231.0.0/17',
+        '50.2.0.0/15',
+        '75.75.224.0/19',
+        '104.140.0.0/16',
+        '104.206.0.0/16',
+        '107.158.0.0/16',
+        '170.130.0.0/16',
+        '173.44.128.0/17',
+        '173.213.64.0/18',
+        '173.232.0.0/16',
+        '206.214.64.0/19',
+        '208.89.216.0/21',
+        '2607:ff28::/32',
+    );
     return $self;
 }
 
@@ -61,7 +63,7 @@ Net::IP::Identifier::Plugin::Eonix - identify Eonix (AS30693) owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
