@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::FDCServers;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,23 +24,25 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known FDCServers (AS30058) IP blocks as of Nov 2014
-    $self->ips(qw(
-        23.237.0.0 - 23.237.255.255
-        50.7.0.0 - 50.7.255.255
-        66.90.64.0 - 66.90.127.255
-        67.159.0.0 - 67.159.63.255
-        74.63.64.0 - 74.63.127.255
-        76.73.0.0 - 76.73.127.255
-        107.176.0.0 - 107.177.255.255
-        108.179.64.0 - 108.179.127.255
-        192.240.96.0 - 192.240.127.255
-        198.16.64.0 - 198.16.127.255
-        198.255.0.0 - 198.255.127.255
-        204.45.0.0 - 204.45.255.255
-        208.53.128.0 - 208.53.191.255
-        216.227.128.0 - 216.227.191.255
-    ));
+    # List of known FDCServers (AS30058) IP blocks as of May 2015
+    $self->ips(
+        '23.237.0.0/16',
+        '50.7.0.0/16',
+        '66.90.64.0/18',
+        '67.159.0.0/18',
+        '74.63.64.0/18',
+        '76.73.0.0/17',
+        '107.176.0.0/15',
+        '108.179.64.0/18',
+        '192.240.96.0/19',
+        '198.16.64.0/18',
+        '198.255.0.0/17',
+        '204.45.0.0/16',
+        '208.53.128.0/18',
+        '216.227.128.0/18',
+        '2001:49f0::/32',
+        # 15 Network Blocks
+    );
     return $self;
 }
 
@@ -62,7 +64,7 @@ Net::IP::Identifier::Plugin::FDCServers - identify FDCServers (AS30058) owned IP
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
