@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Facebook;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,21 +24,24 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Facebook (AS32934) IP blocks as of Oct 2014
-    $self->ips(qw(
-        31.13.24.0 - 31.13.31.255
-        31.13.64.0 - 31.13.127.255
-        45.64.40.0 - 45.64.43.255
-        66.220.144.0 - 66.220.159.255
-        69.63.176.0 - 69.63.191.255
-        69.171.224.0 - 69.171.255.255
-        74.119.76.0 - 74.119.79.255
-        103.4.96.0 - 103.4.99.255
-        173.252.64.0 - 173.252.127.255
-        179.60.192/22
-        185.60.216.0 - 185.60.219.255
-        204.15.20.0 - 204.15.23.255
-    ));
+    # List of known Facebook (AS32934) IP blocks as of May 2015
+    $self->ips(
+        # 14 Network Blocks
+        '31.13.24.0/21',
+        '31.13.64.0/18',
+        '66.220.144.0/20',
+        '69.63.176.0/20',
+        '69.171.224.0/19',
+        '74.119.76.0/22',
+        '173.252.64.0/18',
+        '185.60.216.0/22',
+        '199.201.64.0/22',
+        '204.15.20.0/22',
+        '2401:db00::/32',
+        '2620:0:1c00::/40',
+        '2620:10d:c000::/40',
+        '2a03:2880::/32',
+    );
     return $self;
 }
 
@@ -70,7 +73,7 @@ Net::IP::Identifier::Plugin::Facebook - identify Facebook (AS32934) owned IP add
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
