@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Google;    # _ENTITY_REGEX_ Google|Postini
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,26 +24,27 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-        # List of known Google (AS15169) IP blocks as of August 2014
-    $self->ips(qw(
-        8.8.4.0 - 8.8.4.255
-        8.8.8.0 - 8.8.8.255
-        64.18.0.0 - 64.18.15.255
-        64.233.160.0 - 64.233.191.255
-        66.102.0.0 - 66.102.15.255
-        66.249.64.0 - 66.249.95.255
-        72.14.192.0 - 72.14.255.255
-        74.125.0.0 - 74.125.255.255
-        173.194.0.0 - 173.194.255.255
-        207.126.144.0 - 207.126.159.255
-        209.85.128.0 - 209.85.255.255
-        216.239.32.0 - 216.239.63.255
-        2001:4860:: - 2001:4860:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF
-        2404:6800::/32
-        2607:F8B0:: - 2607:F8B0:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF
-        2800:3f0::/32
-        2c0f:fb50::/32
-    ));
+        # List of known Google (AS15169) IP blocks as of May 2015
+    $self->ips(
+        # 17 Network Blocks
+        '8.8.4.0/24',
+        '8.8.8.0/24',
+        '64.18.0.0/20',
+        '64.233.160.0/19',
+        '66.102.0.0/20',
+        '66.249.64.0/19',
+        '72.14.192.0/18',
+        '74.125.0.0/16',
+        '173.194.0.0/16',
+        '207.126.144.0/20',
+        '209.85.128.0/17',
+        '216.239.32.0/19',
+        '2001:4860::/32',
+        '2404:6800::/32',
+        '2607:f8b0::/32',
+        '2800:3f0::/32',
+        '2c0f:fb50::/32',
+    );
     # NOTE: jwhois 207.126.144.0 - 207.126.159.255 and
     #   64.18.0.0 - 64.18.15.255 indicate Postini, which is 'Google email
     #   security and archiving services'
@@ -92,7 +93,7 @@ Net::IP::Identifier::Plugin::Google - identify Google (AS15169) owned IP address
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
