@@ -11,12 +11,12 @@ use 5.008;
 use strict;
 use warnings;
 
-package Net::IP::Identifier::Plugin::Hotmail;   # _ENTITY_REGEX_ Hotmail|Microsoft
+package Net::IP::Identifier::Plugin::Hotmail;
 
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,12 +24,16 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Hotmail IP blocks as of Oct 2014
-    $self->ips(qw(
-        65.52.0.0 - 65.55.255.255
-        157.54.0.0 - 157.60.255.255
-        207.46.0.0 - 207.46.255.255
-    ));
+    # List of known Hotmail IP blocks as of May 2015
+    $self->ips(
+        '64.4.0.0/18',
+        '65.52.0.0/14',
+        # extending 157.54.0.0/15 to include 157.56.0.0/14
+        # extending 157.54.0.0-157.59.255.255 to include 157.60.0.0/16
+        '157.54.0.0-157.60.255.255',
+        '207.46.0.0/16',
+        # 4 Network Blocks
+    );
     return $self;
 }
 
@@ -51,7 +55,7 @@ Net::IP::Identifier::Plugin::Hotmail - identify Hotmail owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
