@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Inktomi;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,10 +24,14 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Inktomi (AS14778) IP blocks as of Oct 2014
-    $self->ips(qw(
-        72.30.0.0 - 72.30.255.255
-    ));
+    # List of known Inktomi (AS14778) IP blocks as of May 2015
+    $self->ips(
+        # 4 Network Blocks
+        '66.196.64.0/18',
+        '68.142.192.0/18',
+        '72.30.0.0/16',
+        '74.6.0.0/16',
+    );
     return $self;
 }
 
@@ -49,7 +53,7 @@ Net::IP::Identifier::Plugin::Inktomi - identify Inktomi (AS14778) owned IP addre
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
