@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::NephoScale;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,29 +24,31 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known NephoScale (AS13332 AS32105 AS46717) IP blocks as of Oct 2014
-    $self->ips(qw(
-        23.252.240.0 - 23.252.255.255
-        64.58.112.0 - 64.58.127.255
-        66.242.0.0 - 66.242.15.255
-        67.207.192.0 - 67.207.207.255
-        68.169.0.0 - 68.169.31.255
-        69.50.224.0 - 69.50.255.255
-        96.46.176.0 - 96.46.191.255
-        142.0.192.0 - 142.0.207.255
-        142.0.240.0 - 142.0.255.255
-        173.0.144.0 - 173.0.159.255
-        173.233.128.0 - 173.233.159.255
-        173.237.0.0 - 173.237.79.255
-        198.89.96.0 - 198.89.127.255
-        198.100.160.0 - 198.100.191.255
-        199.188.116.0 - 199.188.119.255
-        204.74.224.0 - 204.74.255.255
-        208.69.176.0 - 208.69.183.255
-        208.78.240.0 - 208.78.247.255
-        208.166.48.0 - 208.166.63.255
-        209.205.112.0 - 209.205.127.255
-    ));
+    # List of known NephoScale (AS13332 AS32105 AS46717) IP blocks as of
+    #    May 2015
+    $self->ips(
+        # 19 Network Blocks
+        '23.252.240.0/20',
+        '64.58.112.0/20',
+        '67.207.192.0/20',
+        '69.50.224.0/19',
+        '96.46.176.0/20',
+        '142.0.192.0/20',
+        '142.0.240.0/20',
+        '173.0.144.0/20',
+        '173.233.128.0/19',
+        # extending 173.237.0.0/18 to include 173.237.64.0/20
+        '173.237.0.0-173.237.79.255',
+        '198.89.96.0/19',
+        '198.100.160.0/19',
+        '199.188.116.0/22',
+        '204.74.224.0/19',
+        '208.69.176.0/21',
+        '208.78.240.0/21',
+        '208.166.48.0/20',
+        '2607:e000::/32',
+        '2607:f258::/32',
+    );
     return $self;
 }
 
@@ -68,7 +70,7 @@ Net::IP::Identifier::Plugin::NephoScale - identify NephoScale (AS13332 AS32105 A
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
