@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::OVH;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,36 +24,34 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known OVH (AS16276) IP blocks as of Nov 2014
-    $self->ips(qw(
-        5.39.0.0 - 5.39.127.255
-        5.135.0.0 - 5.135.255.255
-        5.196.0.0 - 5.196.255.255
-        37.59.0.0 - 37.59.255.255
-        37.187.0.0 - 37.187.255.255
-        46.105.0.0 - 46.105.255.255
-        87.98.128.0 - 87.98.191.255
-        91.121.0.0 - 91.121.255.255
-        92.222.0.0 - 92.222.255.255
-        94.23.0.0 - 94.23.255.255
-        109.190.0.0 - 109.190.255.255
-        142.4.192.0 - 142.4.223.255
-        167.114.0.0 - 167.114.255.255
-        176.31.0.0 - 176.31.255.255
-        178.32.0.0 - 178.33.255.255
-        188.165.0.0 - 188.165.255.255
-        192.95.0.0 - 192.95.63.255
-        192.99.0.0 - 192.99.255.255
-        198.27.64.0 - 198.27.127.255
-        198.50.128.0 - 198.50.255.255
-        198.100.144.0 - 198.100.159.255
-        198.245.48.0 - 198.245.63.255
-        213.186.32.0 - 213.186.32.255
-        213.186.50.128 - 213.186.50.159
-        213.186.61.0 - 213.186.61.255
-        213.186.62.0 - 213.186.62.255
-        213.251.128.0 - 213.251.191.255
-    ));
+    # List of known OVH (AS16276) IP blocks as of May 2015
+    $self->ips(
+        # 24 Network Blocks
+        '5.39.0.0/17',
+        '5.135.0.0/16',
+        '5.196.0.0/16',
+        '37.59.0.0/16',
+        '37.187.0.0/16',
+        '46.105.0.0/16',
+        '87.98.128.0/17',
+        '91.121.0.0/16',
+        '92.222.0.0/16',
+        '94.23.0.0/16',
+        '109.190.0.0/16',
+        '142.4.192.0/19',
+        '167.114.0.0/16',
+        '176.31.0.0/16',
+        '178.32.0.0/15',
+        '188.165.0.0/16',
+        '192.95.0.0/18',
+        '192.99.0.0/16',
+        '198.27.64.0/18',
+        '198.50.128.0/17',
+        '198.100.144.0/20',
+        '198.245.48.0/20',
+        '213.186.32.0/19',
+        '213.251.128.0/18',
+    );
     return $self;
 }
 
@@ -75,7 +73,7 @@ Net::IP::Identifier::Plugin::OVH - identify OVH (AS16276) owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
