@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Sagonet;   # _ENTITY_REGEX_  Sago ?net
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,13 +24,17 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Sagonet (AS21840) IP blocks as of Nov 2014
-    $self->ips(qw(
-        64.16.192.0 - 64.16.223.255
-        65.110.32.0 - 65.110.63.255
-        66.118.128.0 - 66.118.191.255
-        207.150.160.0 - 207.150.191.255
-    ));
+    # List of known Sagonet (AS21840) IP blocks as of May 2015
+    $self->ips(
+        # 7 Network Blocks
+        '45.56.192.0/18',
+        '64.16.192.0/19',
+        '65.110.32.0/19',
+        '66.118.128.0/18',
+        '104.243.208.0/20',
+        '104.247.64.0/19',
+        '207.150.160.0/19',
+    );
     return $self;
 }
 
@@ -52,7 +56,7 @@ Net::IP::Identifier::Plugin::Sagonet - identify Sagonet (AS21840) owned IP addre
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
