@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Sharktech;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,22 +24,25 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Sharktech (AS46844) IP blocks as of Nov 2014
-    $self->ips(qw(
-        64.32.0.0 - 64.32.31.255
-        67.21.64.0 - 67.21.95.255
-        70.39.64.0 - 70.39.127.255
-        104.37.244.0 - 104.37.247.255
-        104.160.160.0 - 104.160.191.255
-        104.201.64.0 - 104.201.127.255
-        107.167.0.0 - 107.167.31.255
-        170.178.160.0 - 170.178.191.255
-        174.128.224.0 - 174.128.255.255
-        198.148.80.0 - 198.148.95.255
-        199.115.96.0 - 199.115.103.255
-        204.188.192.0 - 204.188.255.255
-        208.98.0.0 - 208.98.63.255
-    ));
+    # List of known Sharktech (AS46844) IP blocks as of May 2015
+    $self->ips(
+        # 15 Network Blocks
+        '45.58.128.0/18',
+        '64.32.0.0/19',
+        '67.21.64.0/19',
+        '70.39.64.0/18',
+        '104.37.244.0/22',
+        '104.160.160.0/19',
+        '104.201.64.0/18',
+        '107.167.0.0/19',
+        '170.178.160.0/19',
+        '174.128.224.0/19',
+        '198.148.80.0/20',
+        '199.115.96.0/21',
+        '204.188.192.0/18',
+        '208.98.0.0/18',
+        '2610:150::/32',
+    );
     return $self;
 }
 
@@ -61,7 +64,7 @@ Net::IP::Identifier::Plugin::Sharktech - identify Sharktech (AS46844) owned IP a
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
