@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Toqen;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,14 +24,16 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Toqen LLC (AS30186) IP blocks as of Oct 2014
-    $self->ips(qw(
-        108.175.48.0 - 108.175.63.255
-        198.41.96.0 - 198.41.127.255
-        198.54.112.0 - 198.54.127.255
-        199.36.120.0 - 199.36.123.255
-        199.38.240.0 - 199.38.247.255
-    ));
+    # List of known Toqen LLC (AS30186) IP blocks as of May 2015
+    $self->ips(
+        # 6 Network Blocks
+        '108.175.48.0/20',
+        '198.41.96.0/19',
+        '198.54.112.0/20',
+        '199.36.120.0/22',
+        '199.38.240.0/21',
+        '2604:9080::/32',
+    );
     return $self;
 }
 
@@ -53,7 +55,7 @@ Net::IP::Identifier::Plugin::Toqen - identify Toqen LLC (AS30186) owned IP addre
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -63,6 +65,8 @@ version 0.086
 
 Net::IP::Identifier::Plugin::Toqen identifies Toqen LLC (AS30186) host IPs.
 
+These netblocks seem to be owned by Ross Technology Inc. (as of May 2015).
+
 =head2 Methods
 
 =over
