@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::Twitter;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,17 +24,21 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Twitter (AS13414 AS35995 AS54888) IP blocks as of Oct 2014
-    $self->ips(qw(
-        8.25.194.0 - 8.25.195.255
-        8.25.196.0 - 8.25.197.255
-        185.45.4.0 - 185.45.7.255
-        192.133.76.0 - 192.133.79.255
-        199.16.156.0 - 199.16.159.255
-        199.59.148.0 - 199.59.151.255
-        199.96.56.0 - 199.96.63.255
-        209.170.99.0 - 209.170.99.255
-    ));
+    # List of known Twitter (AS13414 AS35995 AS54888) IP blocks as of May 2015.
+    $self->ips(
+        # 10 Network Blocks
+        # extending 8.25.194.0/23 to include 8.25.196.0/23
+        '8.25.194.0-8.25.197.255',
+        '185.45.4.0/22',
+        '192.133.76.0/22',
+        '199.16.156.0/22',
+        '199.59.148.0/22',
+        '199.96.56.0/21',
+        '209.170.99.0/24',
+        '2400:6680::/32',
+        '2620:fe::/40',
+        '2a04:9d40::/29',
+    );
     return $self;
 }
 
@@ -56,7 +60,7 @@ Net::IP::Identifier::Plugin::Twitter - identify Twitter (AS13414 AS35995 AS54888
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
