@@ -1,6 +1,6 @@
 #===============================================================================
 #      PODNAME:  Net::IP::Identifier::Plugin::UPS
-#     ABSTRACT:  identify UPS (AS12217) owned IP addresses
+#     ABSTRACT:  identify UPS (AS4973, AS4972, AS4145, AS12217) owned IP addresses
 #
 #       AUTHOR:  Reid Augustin (REID)
 #        EMAIL:  reid@hellosix.com
@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::UPS;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,11 +24,18 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known UPS (AS12217) IP blocks as of Oct 2014
-    $self->ips(qw(
-        153.2.0.0 - 153.2.255.255
-        156.134.0.0 - 156.134.255.255
-    ));
+    # List of known UPS (AS12217) IP blocks as of May 2015
+    $self->ips(
+        # 8 Network Blocks
+        '63.171.196.0/24',
+        '65.174.66.0/24',
+        '65.174.169.0/24',
+        '153.2.0.0/16',
+        '156.134.0.0/16',
+        '192.55.236.0/24',
+        '205.173.112.0/21',
+        '208.14.182.0/24',
+    );
     return $self;
 }
 
@@ -46,11 +53,11 @@ __END__
 
 =head1 NAME
 
-Net::IP::Identifier::Plugin::UPS - identify UPS (AS12217) owned IP addresses
+Net::IP::Identifier::Plugin::UPS - identify UPS (AS4973, AS4972, AS4145, AS12217) owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -58,7 +65,7 @@ version 0.086
 
 =head1 DESCRIPTION
 
-Net::IP::Identifier::Plugin::UPS identifies UPS (AS12217) host IPs.
+Net::IP::Identifier::Plugin::UPS identifies UPS (AS4973, AS4972, AS4145, AS12217) host IPs.
 
 =head2 Methods
 
