@@ -1,6 +1,6 @@
 #===============================================================================
 #      PODNAME:  Net::IP::Identifier::Plugin::VPLS
-#     ABSTRACT:  identify VPLS/Krypt owned IP addresses
+#     ABSTRACT:  identify VPLS/Krypt (AS45652, AS4213, AS35908) owned IP addresses
 #
 #       AUTHOR:  Reid Augustin (REID)
 #        EMAIL:  reid@hellosix.com
@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::VPLS;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,22 +24,34 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known VPLS/Krypt IP blocks as of Oct 2014
-    $self->ips(qw(
-        66.186.32.0 - 66.186.63.255
-        67.198.128.0 - 67.198.255.255
-        67.229.0.0 - 67.229.255.255
-        74.222.128.0 - 74.222.191.255
-        96.62.0.0 - 96.62.255.255
-        98.126.0.0 - 98.126.255.255
-        103.233.80.0 - 103.233.83.255
-        110.34.128.0 - 110.34.255.255
-        173.214.0.0 - 173.214.127.255
-        174.139.0.0 - 174.139.255.255
-        184.75.176.0 - 184.75.191.255
-        184.83.0.0 - 184.83.255.255
-        209.11.240.0 - 209.11.255.255
-    ));
+    # List of known VPLS/Krypt (AS45652, AS4213, AS35908) IP blocks as of May 2015
+    $self->ips(
+        # 24 Network Blocks
+        '23.91.192.0/19',
+        '23.251.0.0/19',
+        '43.252.120.0/22',
+        '66.186.32.0/19',
+        '67.198.128.0/17',
+        '67.229.0.0/16',
+        '74.222.128.0/18',
+        '96.62.0.0/16',
+        '98.126.0.0/16',
+        '100.43.128.0/18',
+        '103.233.80.0/22',
+        '104.200.192.0/19',
+        '107.6.192.0/18',
+        '110.34.139.0/24',
+        '110.34.220.0/22',
+        '173.214.0.0/17',
+        '174.139.0.0/16',
+        '184.75.176.0/20',
+        '184.83.0.0/16',
+        '184.164.192.0/19',
+        '192.174.96.0/19',
+        '198.61.96.0/19',
+        '209.11.240.0/20',
+        '2607:f180::/31',
+    );
     return $self;
 }
 
@@ -57,11 +69,11 @@ __END__
 
 =head1 NAME
 
-Net::IP::Identifier::Plugin::VPLS - identify VPLS/Krypt owned IP addresses
+Net::IP::Identifier::Plugin::VPLS - identify VPLS/Krypt (AS45652, AS4213, AS35908) owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
