@@ -1,6 +1,6 @@
 #===============================================================================
 #      PODNAME:  Net::IP::Identifier::Plugin::WholeSale
-#     ABSTRACT:  identify WholeSale Internet owned IP addresses
+#     ABSTRACT:  identify WholeSale Internet (AS32097) owned IP addresses
 #
 #       AUTHOR:  Reid Augustin (REID)
 #        EMAIL:  reid@hellosix.com
@@ -16,7 +16,7 @@ package Net::IP::Identifier::Plugin::WholeSale;
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -24,16 +24,21 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known WholeSale Internet IP blocks as of Nov 2014
+    # List of known WholeSale Internet (AS32097) IP blocks as of May 2015
     # (apparently associated with Datashack and Zhou Pizhong)
-    $self->ips(qw(
-        69.30.192.0 - 69.30.255.255
-        69.197.128.0 - 69.197.191.255
-        173.208.128.0 - 173.208.255.255
-        204.12.192.0 - 204.12.255.255
-        208.67.0.0 - 208.67.7.255
-        208.110.64.0 - 208.110.95.255
-    ));
+    $self->ips(
+        '69.30.192.0/18',
+        '69.197.128.0/18',
+        '118.107.0.0/18',
+        '173.208.128.0/17',
+        '185.22.142.0/23',
+        '204.12.192.0/18',
+        '208.67.0.0/21',
+        '208.110.64.0/19',
+        '210.79.16.0/20',
+        '2001:4858::/32',
+        # 10 Network Blocks
+    );
     return $self;
 }
 
@@ -55,11 +60,11 @@ __END__
 
 =head1 NAME
 
-Net::IP::Identifier::Plugin::WholeSale - identify WholeSale Internet owned IP addresses
+Net::IP::Identifier::Plugin::WholeSale - identify WholeSale Internet (AS32097) owned IP addresses
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
