@@ -17,12 +17,11 @@ use Role::Tiny;
 use Net::IP;
 use Net::IP::Identifier::Net;
 
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.106'; # VERSION
 
 requires qw( new name );
 
 use overload (
-    fallback => 1,
     '""' => 'name',
 );
 
@@ -117,7 +116,7 @@ Net::IP::Identifier_Role - The role that Net::IP::Identifier plugins must satisf
 
 =head1 VERSION
 
-version 0.086
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -218,7 +217,7 @@ This accessor/method sets or clears a flag that modifies the return value
 of the B<identify> method.  When clear, the return value of B<identify> is
 the entity object (which stringifies to the entities B<name> method).  When
 set, the returned object is instead the Net::IP::Identifier::Net object
-(which stringifies to the B<as_string> method).
+(which stringifies to the B<print> method).
 
 =item refresh
 
